/////////////////////////////////////////////////////////////////////////////
//
// File    : MemDC.cpp
// Author  : Keith Rule (keithr@europa.com)
// Date    : 1997.xx.xx
// Purpose : Implementation of Memory Device Context
//
// Copyright(C) 1996-1997 Keith Rule
// All rights reserved.
// You may freely use or modify this code provided this
// Copyright is included in all derived versions.
//
/////////////////////////////////////////////////////////////////////////////
// Revision History:
//
// 1997.03.10 Fixed scrolling bug, Added print support.
// 1998.02.25 Fixed minor assertion bug.
//
/////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "MemDC.h"

#ifdef _DEBUG
#undef THIS_FILE
static char					THIS_FILE[] = __FILE__;
#define new DEBUG_NEW
#endif

/////////////////////////////////////////////////////////////////////////////
// Pre-Class Declarations
/////////////////////////////////////////////////////////////////////////////


/////////////////////////////////////////////////////////////////////////////
//
// Constructor & Destructor
//
/////////////////////////////////////////////////////////////////////////////
//===========================================================================
CMyMemDC::CMyMemDC(CDC *pDC)
//===========================================================================
{
	CDC();
	//
	ASSERT(pDC != NULL);
	//
	m_pDC			= pDC;
	m_pOldBitmap	= NULL;
#ifndef WCE_NO_PRINTING
	m_bMemDC		= !pDC->IsPrinting();
#else
	m_bMemDC = FALSE;
#endif // WCE_NO_PRINTING
	//
	if(m_bMemDC) // Create a Memory DC
	{
		pDC->GetClipBox(&m_rect);
		CreateCompatibleDC(pDC);
		m_Bitmap.CreateCompatibleBitmap(pDC, m_rect.Width(), m_rect.Height());
		m_pOldBitmap = SelectObject(&m_Bitmap);
#ifndef _WIN32_WCE
		SetWindowOrg(m_rect.left, m_rect.top);
#endif
	}
	else // if(!m_bMemDC) // Make a copy of the relevant parts of the current DC for printing
	{
#ifndef WCE_NO_PRINTING
		m_bPrinting	= pDC->m_bPrinting;
#endif
		m_hDC		= pDC->m_hDC;
		m_hAttribDC	= pDC->m_hAttribDC;
	}
}

//===========================================================================
CMyMemDC::~CMyMemDC()
//===========================================================================
{
	if(m_bMemDC)
	{
		m_pDC->BitBlt(m_rect.left, m_rect.top, m_rect.Width(), m_rect.Height(),
						this, m_rect.left, m_rect.top, SRCCOPY);
		//
		SelectObject(m_pOldBitmap); // Swap back the original bitmap
	}
	else // if(!m_bMemDC)
	{
		// Invalid assign keeps us from accidently deleting the handles associated with CDC
		m_hDC = NULL;
		m_hAttribDC = NULL;
	}
}

/////////////////////////////////////////////////////////////////////////////
//
// Implementations
//
/////////////////////////////////////////////////////////////////////////////


/////////////////////////////////////////////////////////////////////////////
//
// Interfaces
//
/////////////////////////////////////////////////////////////////////////////


/////////////////////////////////////////////////////////////////////////////
//
// Overrides
//
/////////////////////////////////////////////////////////////////////////////
